==> perl-doc-html_5.10.1.orig.tar.gz: perldoc-html-5.10.1/static/indexPod.js <==
perldocSearch.indexData.pod = new Hash ({
  "perl": "Practical Extraction and Report Language",
  "perlintro": "a brief introduction and overview of Perl",
  "perlrun": "how to execute the Perl interpreter",
  "perlbook": "Perl book information",
  "perlcommunity": "a brief overview of the Perl community",
  "perlreftut": "Mark's very short tutorial about references",
  "perldsc": "data structure complex data structure struct",
  "perllol": "Manipulating Arrays of Arrays in Perl",
  "perlrequick": "Perl regular expressions quick start",
  "perlretut": "Perl regular expressions tutorial",
  "perlboot": "Beginner's Object-Oriented Tutorial",
  "perltoot": "Tom's object-oriented tutorial for perl",
  "perltooc": "Tom's OO Tutorial for Class Data in Perl",
  "perlbot": "Bag'o Object Tricks (the BOT)",
  "perlstyle": "Perl style guide",
  "perlcheat": "Perl 5 Cheat Sheet",
  "perltrap": "Perl traps for the unwary",
  "perldebtut": "Perl debugging tutorial",
  "perlopentut": "tutorial on opening things in Perl",
  "perlpacktut": "tutorial on pack and unpack",
  "perlthrtut": "Tutorial on threads in Perl",
  "perlothrtut": "old tutorial on threads in Perl",
  "perlxstut": "Tutorial for writing XSUBs",
  "perlunitut": "Perl Unicode Tutorial",
  "perlpragma": "how to write a user pragma",
  "perlfaq": "frequently asked questions about Perl",
  "perlfaq1": "General Questions About Perl",
  "perlfaq2": "Obtaining and Learning about Perl",
  "perlfaq3": "Programming Tools",
  "perlfaq4": "Data Manipulation",
  "perlfaq5": "Files and Formats",
  "perlfaq6": "Regular Expressions",
  "perlfaq7": "General Perl Language Issues",
  "perlfaq8": "System Interaction",
  "perlfaq9": "Networking",
  "perlunifaq": "Perl Unicode FAQ",
  "perlsyn": "syntax",
  "perldata": "Perl data types",
  "perlsub": "subroutine function",
  "perlop": "operator",
  "perlfunc": "function",
  "perlpod": "POD plain old documentation",
  "perlpodspec": "Plain Old Documentation: format specification and notes",
  "perldiag": "various Perl diagnostics",
  "perllexwarn": "warning, lexical warnings warning",
  "perldebug": "debug debugger",
  "perlvar": "Perl predefined variables",
  "perlre": "regular expression regex regexp",
  "perlreref": "Perl Regular Expressions Reference",
  "perlref": "reference pointer data structure structure struct",
  "perlform": "format report chart",
  "perlobj": "object OOP",
  "perltie": "tie",
  "perldbmfilter": "Perl DBM Filters",
  "perlipc": "Perl interprocess communication (signals, fifos, pipes, safe subprocesses, sockets, and semaphores)",
  "perlfork": "Perl's fork() emulation",
  "perlnumber": "semantics of numbers and numeric operations in Perl",
  "perlperf": "Perl Performance and Optimization Techniques",
  "perlport": "Writing portable Perl",
  "perllocale": "Perl locale handling (internationalization and localization)",
  "perluniintro": "Perl Unicode introduction",
  "perlunicode": "Unicode support in Perl",
  "perlebcdic": "Considerations for running Perl on EBCDIC platforms",
  "perlsec": "Perl security",
  "perlmod": "Perl modules (packages and symbol tables)",
  "perlmodlib": "constructing new Perl modules and finding existing ones",
  "perlmodstyle": "Perl module style guide",
  "perlmodinstall": "Installing CPAN Modules",
  "perlnewmod": "preparing a new module for distribution",
  "perlcompile": "Introduction to the Perl Compiler-Translator ",
  "perlfilter": "Source Filters",
  "perlglossary": "Perl Glossary",
  "CORE": "Pseudo-namespace for Perl's core routines",
  "perlembed": "how to embed perl in your C program",
  "perldebguts": "Guts of Perl debugging ",
  "perlxs": "XS language reference manual",
  "perlxstut": "Tutorial for writing XSUBs",
  "perlrepository": "Using the Perl source repository",
  "perlclib": "Internal replacements for standard C library functions",
  "perlguts": "Introduction to the Perl API",
  "perlcall": "Perl calling conventions from C",
  "perlapi": "autogenerated documentation for the perl public API",
  "perlintern": "autogenerated documentation of purely internal		 Perl functions",
  "perlmroapi": "Perl method resolution plugin interface",
  "perliol": "C API for Perl's implementation of IO in Layers.",
  "perlapio": "perl's IO abstraction interface.",
  "perlhack": "How to hack at the Perl internals",
  "perlreguts": "Description of the Perl regular expression engine.",
  "perlreapi": "perl regular expression plugin interface",
  "perlhist": "the Perl history records",
  "perltodo": "Perl TO-DO List",
  "perldelta": "what is new for perl v5.10.1",
  "perl595delta": "what is new for perl v5.9.5",
  "perl594delta": "what is new for perl v5.9.4",
  "perl593delta": "what is new for perl v5.9.3",
  "perl592delta": "what is new for perl v5.9.2",
  "perl591delta": "what is new for perl v5.9.1",
  "perl590delta": "what is new for perl v5.9.0",
  "perl589delta": "what is new for perl v5.8.9",
  "perl588delta": "what is new for perl v5.8.8",
  "perl587delta": "what is new for perl v5.8.7",
  "perl586delta": "what is new for perl v5.8.6",
  "perl585delta": "what is new for perl v5.8.5",
  "perl584delta": "what is new for perl v5.8.4",
  "perl583delta": "what is new for perl v5.8.3",
  "perl582delta": "what is new for perl v5.8.2",
  "perl581delta": "what is new for perl v5.8.1",
  "perl58delta": "what is new for perl v5.8.0",
  "perl573delta": "what's new for perl v5.7.3",
  "perl572delta": "what's new for perl v5.7.2",
  "perl571delta": "what's new for perl v5.7.1",
  "perl570delta": "what's new for perl v5.7.0",
  "perl561delta": "what's new for perl v5.6.x",
  "perl56delta": "what's new for perl v5.6.0",
  "perl5101delta": "what is new for perl v5.10.1",
  "perl5100delta": "what is new for perl 5.10.0",
  "perl5005delta": "what's new for perl5.005",
  "perl5004delta": "what's new for perl5.004",
  "perlartistic": "the Perl Artistic License",
  "perlgpl": "the GNU General Public License, version 2",
  "perlaix": "Perl version 5 on IBM Unix (AIX) systems",
  "perlamiga": "Perl under Amiga OS",
  "perlapollo": "Perl version 5 on Apollo DomainOS",
  "perlbeos": "Perl version 5.8+ on BeOS",
  "perlbs2000": "building and installing Perl for BS2000.",
  "perlce": "Perl for WinCE",
  "perlcygwin": "Perl for Cygwin",
  "perldgux": "Perl under DG/UX.",
  "perldos": "Perl under DOS, W31, W95.",
  "perlepoc": "Perl for EPOC",
  "perlfreebsd": "Perl version 5 on FreeBSD systems",
  "perlhaiku": "Perl version 5.10+ on Haiku",
  "perlhpux": "Perl version 5 on Hewlett-Packard Unix (HP-UX) systems",
  "perlhurd": "Perl version 5 on Hurd",
  "perlirix": "Perl version 5 on Irix systems",
  "perllinux": "Perl version 5 on Linux systems",
  "perlmachten": "Perl version 5 on Power MachTen systems",
  "perlmacos": "Perl under Mac OS (Classic)",
  "perlmacosx": "Perl under Mac OS X",
  "perlmint": "Perl version 5 on Atari MiNT",
  "perlmpeix": "Perl/iX for HP e3000 MPE",
  "perlnetware": "Perl for NetWare",
  "perlos2": "Perl under OS/2, DOS, Win0.3*, Win0.95 and WinNT.",
  "perlos390": "building and installing Perl for OS/390 and z/OS",
  "perlos400": "Perl version 5 on OS/400",
  "perlplan9": "Plan 9-specific documentation for Perl",
  "perlqnx": "Perl version 5 on QNX",
  "perlsolaris": "Perl version 5 on Solaris systems",
  "perlsymbian": "Perl version 5 on Symbian OS",
  "perltru64": "Perl version 5 on Tru64 (formerly known as Digital UNIX formerly known as DEC OSF/1) systems",
  "perluts": "Perl under UTS",
  "perlvmesa": "building and installing Perl for VM/ESA.",
  "perlvms": "VMS-specific documentation for Perl",
  "perlvos": "Perl for Stratus VOS",
  "perlwin32": "Perl under Windows",
  "perlutil": "utilities packaged with the Perl distribution",
  "a2p": "Awk to Perl translator",
  "c2ph": "Dump C structures as generated from cc -g -S stabs",
  "config_data": "Query or change configuration of Perl modules",
  "corelist": "a commandline frontend to Module::CoreList",
  "cpan": "easily interact with CPAN from the command line",
  "cpanp": "The CPANPLUS launcher",
  "cpan2dist": "The CPANPLUS distribution creator",
  "dprofpp": "display perl profile data",
  "enc2xs": "Perl Encode Module Generator",
  "find2perl": "translate find command lines to Perl code",
  "h2ph": "convert .h C header files to .ph Perl header files",
  "h2xs": "convert .h C header files to Perl extensions",
  "instmodsh": "A shell to examine installed modules",
  "libnetcfg": "configure libnet",
  "perlbug": "how to submit bug reports on Perl",
  "piconv": "iconv(1), reinvented in perl",
  "prove": "Run tests through a TAP harness.",
  "psed": "a stream editor",
  "podchecker": "check the syntax of POD format documentation files",
  "perldoc": "Look up Perl documentation in Pod format.",
  "perlivp": "Perl Installation Verification Procedure",
  "pod2html": "convert .pod files to .html files",
  "pod2latex": "convert pod documentation to latex format",
  "pod2man": "Convert POD data to formatted *roff input",
  "pod2text": "Convert POD data to formatted ASCII text",
  "pod2usage": "print usage messages from embedded pod docs in files",
  "podselect": "print selected sections of pod documentation on standard output",
  "pstruct": "Dump C structures as generated from cc -g -S stabs",
  "ptar": "1",
  "ptardiff": "program that diffs an extracted archive against an unextracted one",
  "s2p": "a stream editor",
  "shasum": "Print or Check SHA Checksums",
  "splain": "produce verbose warning diagnostics",
  "xsubpp": "compiler to convert Perl XS code into C code",
  "perlthanks": "how to submit bug reports on Perl"
});

==> perl-doc-html_5.14.0.orig.tar.gz: perldoc-html-5.14.0/static/indexPod.js <==
perldocSearch.indexData.pod = new Hash ({
  "perl": "The Perl 5 language interpreter",
  "perlintro": "a brief introduction and overview of Perl",
  "perlrun": "how to execute the Perl interpreter",
  "perlbook": "Books about and related to Perl",
  "perlcommunity": "a brief overview of the Perl community",
  "perlreftut": "Mark's very short tutorial about references",
  "perldsc": "data structure complex data structure struct",
  "perllol": "Manipulating Arrays of Arrays in Perl",
  "perlrequick": "Perl regular expressions quick start",
  "perlretut": "Perl regular expressions tutorial",
  "perlboot": "Beginner's Object-Oriented Tutorial",
  "perltoot": "Tom's object-oriented tutorial for perl",
  "perltooc": "Tom's OO Tutorial for Class Data in Perl",
  "perlbot": "Bag o' Object Tricks (the BOT)",
  "perlstyle": "Perl style guide",
  "perlcheat": "Perl 5 Cheat Sheet",
  "perltrap": "Perl traps for the unwary",
  "perldebtut": "Perl debugging tutorial",
  "perlopentut": "tutorial on opening things in Perl",
  "perlpacktut": "tutorial on pack and unpack",
  "perlthrtut": "Tutorial on threads in Perl",
  "perlxstut": "Tutorial for writing XSUBs",
  "perlunitut": "Perl Unicode Tutorial",
  "perlpragma": "how to write a user pragma",
  "perlfaq": "frequently asked questions about Perl",
  "perlfaq1": "General Questions About Perl",
  "perlfaq2": "Obtaining and Learning about Perl",
  "perlfaq3": "Programming Tools",
  "perlfaq4": "Data Manipulation",
  "perlfaq5": "Files and Formats",
  "perlfaq6": "Regular Expressions",
  "perlfaq7": "General Perl Language Issues",
  "perlfaq8": "System Interaction",
  "perlfaq9": "Networking",
  "perlunifaq": "Perl Unicode FAQ",
  "perlsyn": "syntax",
  "perldata": "Perl data types",
  "perlsub": "subroutine function",
  "perlop": "operator",
  "perlfunc": "function",
  "perlpod": "POD plain old documentation",
  "perlpodspec": "Plain Old Documentation: format specification and notes",
  "perlpodstyle": "Perl POD style guide",
  "perldiag": "various Perl diagnostics",
  "perllexwarn": "warning, lexical warnings warning",
  "perldebug": "debug debugger",
  "perlvar": "Perl predefined variables",
  "perlre": "regular expression regex regexp",
  "perlreref": "Perl Regular Expressions Reference",
  "perlrebackslash": "Perl Regular Expression Backslash Sequences and Escapes",
  "perlrecharclass": "character class",
  "perlref": "reference pointer data structure structure struct",
  "perlform": "format report chart",
  "perlobj": "object OOP",
  "perltie": "tie",
  "perldbmfilter": "Perl DBM Filters",
  "perlipc": "Perl interprocess communication (signals, fifos, pipes, safe subprocesses, sockets, and semaphores)",
  "perlfork": "Perl's fork() emulation",
  "perlnumber": "semantics of numbers and numeric operations in Perl",
  "perlperf": "Perl Performance and Optimization Techniques",
  "perlport": "Writing portable Perl",
  "perllocale": "Perl locale handling (internationalization and localization)",
  "perluniintro": "Perl Unicode introduction",
  "perlunicode": "Unicode support in Perl",
  "perluniprops": "Index of Unicode Version 6.0.0 properties in Perl",
  "perlebcdic": "Considerations for running Perl on EBCDIC platforms",
  "perlsec": "Perl security",
  "perlmod": "Perl modules (packages and symbol tables)",
  "perlmodlib": "constructing new Perl modules and finding existing ones",
  "perlmodstyle": "Perl module style guide",
  "perlmodinstall": "Installing CPAN Modules",
  "perlnewmod": "preparing a new module for distribution",
  "perlcompile": "Introduction to the Perl Compiler-Translator ",
  "perlfilter": "Source Filters",
  "perlglossary": "Perl Glossary",
  "CORE": "Pseudo-namespace for Perl's core routines",
  "perlembed": "how to embed perl in your C program",
  "perldebguts": "Guts of Perl debugging ",
  "perlxs": "XS language reference manual",
  "perlxstut": "Tutorial for writing XSUBs",
  "perlinterp": "An overview of the Perl interpreter",
  "perlsource": "A guide to the Perl source tree",
  "perlclib": "Internal replacements for standard C library functions",
  "perlguts": "Introduction to the Perl API",
  "perlcall": "Perl calling conventions from C",
  "perlapi": "autogenerated documentation for the perl public API",
  "perlintern": "autogenerated documentation of purely internal		 Perl functions",
  "perlmroapi": "Perl method resolution plugin interface",
  "perliol": "C API for Perl's implementation of IO in Layers.",
  "perlapio": "perl's IO abstraction interface.",
  "perlhack": "How to hack on Perl",
  "perlhacktut": "Walk through the creation of a simple C code patch",
  "perlhacktips": "Tips for Perl core C code hacking",
  "perlreguts": "Description of the Perl regular expression engine.",
  "perlreapi": "perl regular expression plugin interface",
  "perlpolicy": "Various and sundry policies and commitments related to the Perl core",
  "perlhist": "the Perl history records",
  "perltodo": "Perl TO-DO List",
  "perldelta": "what is new for perl v5.14.0",
  "perl5140delta": "what is new for perl v5.14.0",
  "perl51311delta": "what is new for perl v5.13.11",
  "perl51310delta": "what is new for perl v5.13.10",
  "perl5139delta": "what is new for perl v5.13.9",
  "perl5138delta": "what is new for perl v5.13.8",
  "perl5137delta": "what is new for perl v5.13.7",
  "perl5136delta": "what is new for perl v5.13.6",
  "perl5135delta": "what is new for perl v5.13.5",
  "perl5134delta": "what is new for perl v5.13.4",
  "perl5133delta": "what is new for perl v5.13.3",
  "perl5132delta": "what is new for perl v5.13.2",
  "perl5131delta": "what is new for perl v5.13.1",
  "perl5130delta": "what is new for perl v5.13.0",
  "perl5123delta": "what is new for perl v5.12.3",
  "perl5122delta": "what is new for perl v5.12.2",
  "perl5121delta": "what is new for perl v5.12.1",
  "perl5120delta": "what is new for perl v5.12.0",
  "perl5115delta": "what is new for perl v5.11.5",
  "perl5114delta": "what is new for perl v5.11.4",
  "perl5113delta": "what is new for perl v5.11.3",
  "perl5112delta": "what is new for perl v5.11.2",
  "perl5111delta": "what is new for perl v5.11.1",
  "perl5110delta": "what is new for perl v5.11.0",
  "perl5101delta": "what is new for perl v5.10.1",
  "perl5100delta": "what is new for perl 5.10.0",
  "perl595delta": "what is new for perl v5.9.5",
  "perl594delta": "what is new for perl v5.9.4",
  "perl593delta": "what is new for perl v5.9.3",
  "perl592delta": "what is new for perl v5.9.2",
  "perl591delta": "what is new for perl v5.9.1",
  "perl590delta": "what is new for perl v5.9.0",
  "perl589delta": "what is new for perl v5.8.9",
  "perl588delta": "what is new for perl v5.8.8",
  "perl587delta": "what is new for perl v5.8.7",
  "perl586delta": "what is new for perl v5.8.6",
  "perl585delta": "what is new for perl v5.8.5",
  "perl584delta": "what is new for perl v5.8.4",
  "perl583delta": "what is new for perl v5.8.3",
  "perl582delta": "what is new for perl v5.8.2",
  "perl581delta": "what is new for perl v5.8.1",
  "perl58delta": "what is new for perl v5.8.0",
  "perl573delta": "what's new for perl v5.7.3",
  "perl572delta": "what's new for perl v5.7.2",
  "perl571delta": "what's new for perl v5.7.1",
  "perl570delta": "what's new for perl v5.7.0",
  "perl561delta": "what's new for perl v5.6.x",
  "perl56delta": "what's new for perl v5.6.0",
  "perl5005delta": "what's new for perl5.005",
  "perl5004delta": "what's new for perl5.004",
  "perlartistic": "the Perl Artistic License",
  "perlgpl": "the GNU General Public License, version 1",
  "perlaix": "Perl version 5 on IBM AIX (UNIX) systems",
  "perlamiga": "Perl under Amiga OS",
  "perlbeos": "Perl version 5.8+ on BeOS",
  "perlbs2000": "building and installing Perl for BS2000.",
  "perlce": "Perl for WinCE",
  "perlcygwin": "Perl for Cygwin",
  "perldgux": "Perl under DG/UX.",
  "perldos": "Perl under DOS, W31, W95.",
  "perlepoc": "Perl for EPOC",
  "perlfreebsd": "Perl version 5 on FreeBSD systems",
  "perlhaiku": "Perl version 5.10+ on Haiku",
  "perlhpux": "Perl version 5 on Hewlett-Packard Unix (HP-UX) systems",
  "perlhurd": "Perl version 5 on Hurd",
  "perlirix": "Perl version 5 on Irix systems",
  "perllinux": "Perl version 5 on Linux systems",
  "perlmacos": "Perl under Mac OS (Classic)",
  "perlmacosx": "Perl under Mac OS X",
  "perlmpeix": "Perl/iX for HP e3000 MPE",
  "perlnetware": "Perl for NetWare",
  "perlopenbsd": "Perl version 5 on OpenBSD systems",
  "perlos2": "Perl under OS/2, DOS, Win0.3*, Win0.95 and WinNT.",
  "perlos390": "building and installing Perl for OS/390 and z/OS",
  "perlos400": "Perl version 5 on OS/400",
  "perlplan9": "Plan 9-specific documentation for Perl",
  "perlqnx": "Perl version 5 on QNX",
  "perlriscos": "Perl version 5 for RISC OS",
  "perlsolaris": "Perl version 5 on Solaris systems",
  "perlsymbian": "Perl version 5 on Symbian OS",
  "perltru64": "Perl version 5 on Tru64 (formerly known as Digital UNIX formerly known as DEC OSF/1) systems",
  "perluts": "Perl under UTS",
  "perlvmesa": "building and installing Perl for VM/ESA.",
  "perlvms": "VMS-specific documentation for Perl",
  "perlvos": "Perl for Stratus VOS",
  "perlwin32": "Perl under Windows",
  "perlutil": "utilities packaged with the Perl distribution",
  "a2p": "Awk to Perl translator",
  "c2ph": "Dump C structures as generated from cc -g -S stabs",
  "config_data": "Query or change configuration of Perl modules",
  "corelist": "a commandline frontend to Module::CoreList",
  "cpan": "easily interact with CPAN from the command line",
  "cpanp": "The CPANPLUS launcher",
  "cpan2dist": "The CPANPLUS distribution creator",
  "dprofpp": "display perl profile data",
  "enc2xs": "Perl Encode Module Generator",
  "find2perl": "translate find command lines to Perl code",
  "h2ph": "convert .h C header files to .ph Perl header files",
  "h2xs": "convert .h C header files to Perl extensions",
  "instmodsh": "A shell to examine installed modules",
  "libnetcfg": "configure libnet",
  "perlbug": "how to submit bug reports on Perl",
  "piconv": "iconv(1), reinvented in perl",
  "prove": "Run tests through a TAP harness.",
  "psed": "a stream editor",
  "podchecker": "check the syntax of POD format documentation files",
  "perldoc": "Look up Perl documentation in Pod format.",
  "perlivp": "Perl Installation Verification Procedure",
  "pod2html": "convert .pod files to .html files",
  "pod2latex": "convert pod documentation to latex format",
  "pod2man": "Convert POD data to formatted *roff input",
  "pod2text": "Convert POD data to formatted ASCII text",
  "pod2usage": "print usage messages from embedded pod docs in files",
  "podselect": "print selected sections of pod documentation on standard output",
  "pstruct": "Dump C structures as generated from cc -g -S stabs",
  "ptar": "1",
  "ptardiff": "program that diffs an extracted archive against an unextracted one",
  "s2p": "a stream editor",
  "shasum": "Print or Check SHA Checksums",
  "splain": "produce verbose warning diagnostics",
  "xsubpp": "compiler to convert Perl XS code into C code",
  "perlthanks": "how to submit bug reports on Perl"
});
